@@ -1,10 +1,9 @@
-
-/* A Bison parser, made by GNU Bison 2.4.1.  */
+/* A Bison parser, made by GNU Bison 2.4.3.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2009, 2010 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -61,35 +60,36 @@
      ARRAY_DIM = 277,
      SINGLE_CHAR = 278,
      CCODE = 279,
-     ADCODE = 280,
-     HTCODE = 281,
-     PHCODE = 282,
-     HCODE = 283,
-     ACODE = 284,
-     ATCODE = 285,
-     STRING = 286,
-     PUBLIC = 287,
-     PRIVATE = 288,
-     PROTECTED = 289,
-     CLASSWIDE = 290,
-     PROPERTY = 291,
-     ARGUMENT = 292,
-     VIRTUAL = 293,
-     SIGNAL = 294,
-     OVERRIDE = 295,
-     NICK = 296,
-     BLURB = 297,
-     MAXIMUM = 298,
-     MINIMUM = 299,
-     DEFAULT_VALUE = 300,
-     ERROR = 301,
-     FLAGS = 302,
-     TYPE = 303,
-     FLAGS_TYPE = 304,
-     ENUM_TYPE = 305,
-     PARAM_TYPE = 306,
-     BOXED_TYPE = 307,
-     OBJECT_TYPE = 308
+     CTCODE = 280,
+     ADCODE = 281,
+     HTCODE = 282,
+     PHCODE = 283,
+     HCODE = 284,
+     ACODE = 285,
+     ATCODE = 286,
+     STRING = 287,
+     PUBLIC = 288,
+     PRIVATE = 289,
+     PROTECTED = 290,
+     CLASSWIDE = 291,
+     PROPERTY = 292,
+     ARGUMENT = 293,
+     VIRTUAL = 294,
+     SIGNAL = 295,
+     OVERRIDE = 296,
+     NICK = 297,
+     BLURB = 298,
+     MAXIMUM = 299,
+     MINIMUM = 300,
+     DEFAULT_VALUE = 301,
+     ERROR = 302,
+     FLAGS = 303,
+     TYPE = 304,
+     FLAGS_TYPE = 305,
+     ENUM_TYPE = 306,
+     PARAM_TYPE = 307,
+     BOXED_TYPE = 308,
+     OBJECT_TYPE = 309
    };
 #endif
 /* Tokens.  */
@@ -115,35 +115,36 @@
 #define ARRAY_DIM 277
 #define SINGLE_CHAR 278
 #define CCODE 279
-#define ADCODE 280
-#define HTCODE 281
-#define PHCODE 282
-#define HCODE 283
-#define ACODE 284
-#define ATCODE 285
-#define STRING 286
-#define PUBLIC 287
-#define PRIVATE 288
-#define PROTECTED 289
-#define CLASSWIDE 290
-#define PROPERTY 291
-#define ARGUMENT 292
-#define VIRTUAL 293
-#define SIGNAL 294
-#define OVERRIDE 295
-#define NICK 296
-#define BLURB 297
-#define MAXIMUM 298
-#define MINIMUM 299
-#define DEFAULT_VALUE 300
-#define ERROR 301
-#define FLAGS 302
-#define TYPE 303
-#define FLAGS_TYPE 304
-#define ENUM_TYPE 305
-#define PARAM_TYPE 306
-#define BOXED_TYPE 307
-#define OBJECT_TYPE 308
+#define CTCODE 280
+#define ADCODE 281
+#define HTCODE 282
+#define PHCODE 283
+#define HCODE 284
+#define ACODE 285
+#define ATCODE 286
+#define STRING 287
+#define PUBLIC 288
+#define PRIVATE 289
+#define PROTECTED 290
+#define CLASSWIDE 291
+#define PROPERTY 292
+#define ARGUMENT 293
+#define VIRTUAL 294
+#define SIGNAL 295
+#define OVERRIDE 296
+#define NICK 297
+#define BLURB 298
+#define MAXIMUM 299
+#define MINIMUM 300
+#define DEFAULT_VALUE 301
+#define ERROR 302
+#define FLAGS 303
+#define TYPE 304
+#define FLAGS_TYPE 305
+#define ENUM_TYPE 306
+#define PARAM_TYPE 307
+#define BOXED_TYPE 308
+#define OBJECT_TYPE 309
 
 
 
@@ -152,7 +153,7 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
+/* Line 1685 of yacc.c  */
 #line 683 "parse.y"
 
 	char *id;
@@ -163,8 +164,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 1676 of yacc.c  */
-#line 168 "parse.h"
+/* Line 1685 of yacc.c  */
+#line 169 "parse.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
